Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::concepts::CallablePredicate Member List

This is the complete list of members for ranges::v3::concepts::CallablePredicate, including all inherited members.

base_concepts_t typedef (defined in ranges::v3::concepts::refines< RegularCallable >) | ranges::v3::concepts::refines< RegularCallable > |
refines()=delete (defined in ranges::v3::concepts::refines< RegularCallable >) | ranges::v3::concepts::refines< RegularCallable > |
requires_(Fun &&, Args &&...) -> decltype( concepts::valid_expr( concepts::model_of< Predicate, function_type< Fun >, Args... >() )) (defined in ranges::v3::concepts::CallablePredicate) | ranges::v3::concepts::CallablePredicate |
requires_(Ts &&...) (defined in ranges::v3::concepts::refines< RegularCallable >) | ranges::v3::concepts::refines< RegularCallable > |